# Description: A list of adjectives and animals to use in the Ubuntu Namer
# We aim to keep these names non-offensive, non-derogatory, and short-ish.

ubuntu_names = {
    "a": {
        "adjectives": [
            "Able",
            "Acute",
            "Adventurous",
            "Aggravated",
            "Agile",
            "Amazing",
            "Ambling",
            "Amicable",
            "Anarchic",
            "Androgynous",
            "Angelic",
            "Annoying",
            "Antlered",
            "Antsy",
            "Archaic",
            "Aromatic",
            "Artsy",
            "Astonishing",
            "Astounding",
            "Astute",
            "Athletic",
            "Atomic",
            "Attractive",
            "Austere",
            "Avid",
            "Avuncular",
            "Aware",
            "Awesome",
            "Awkward",
        ],
        "animals": [
            "Aal",
            "Aardvark",
            "Affenpinscher",
            "Agama",
            "Albatross",
            "Alligator",
            "Alpaca",
            "Amoeba",
            "Anemone",
            "Angelfish",
            "Anoa",
            "Ant",
            "Anteater",
            "Antelope",
            "Ape",
            "Arachnid",
            "Armadillo",
            "Asp",
            "Avocet",
            "Axolotl",
            "Aye Aye",
        ],
    },
    "b": {
        "adjectives": [
            "Baffling",
            "Bamboozling",
            "Barking",
            "Bashful",
            "Batty",
            "Bawdy",
            "Beaming",
            "Beautiful",
            "Befuddled",
            "Beguiling",
            "Belching",
            "Bellicose",
            "Belligerent",
            "Benevolent",
            "Bent",
            "Bewildered",
            "Bewitched",
            "Big",
            "Blustering",
            "Boggling",
            "Boisterous",
            "Bounding",
            "Brainy",
            "Brave",
            "Brazen",
            "Breezy",
            "Bright",
            "Brilliant",
            "Bumpy",
            "Bustling",
            "Busy",
            "Buzzy",
        ],
        "animals": [
            "Baboon",
            "Badger",
            "Barnacle",
            "Barracuda",
            "Bat",
            "Beagle",
            "Bear",
            "Beaver",
            "Bee",
            "Beetle",
            "Bison",
            "Bittern",
            "Blackbird",
            "Blowfish",
            "Bluejay",
            "Bobcat",
            "Bonobo",
            "Booby",
            "Bothrop",
            "Bowerbird",
            "Buck",
            "Bull",
            "Bunny",
        ],
    },
    "c": {
        "adjectives": [
            "Calculating",
            "Campy",
            "Canny",
            "Careful",
            "Cavalier",
            "Celebrity",
            "Cerebral",
            "Charming",
            "Cheeky",
            "Cheerful",
            "Cheesy",
            "Chirping",
            "Chonky",
            "Chummy",
            "Clever",
            "Clumsy",
            "Colonel",
            "Cool",
            "Cosmic",
            "Courageous",
            "Coy",
            "Crafty",
            "Cranky",
            "Crooked",
            "Cuddly",
            "Cunning",
            "Curious",
            "Curt",
            "Cute",
            "Cynical",
        ],
        "animals": [
            "Camel",
            "Canine",
            "Capybara",
            "Caracal",
            "Cardinal",
            "Caribou",
            "Carnivore",
            "Cassowary",
            "Cat",
            "Caterpillar",
            "Centipede",
            "Chameleon",
            "Chapulín",
            "Cheetah",
            "Chickadee",
            "Chicken",
            "Chimp",
            "Chinchilla",
            "Chipmunk",
            "Chupacabra",
            "Coati",
            "Cobra",
            "Cockatoo",
            "Condor",
            "Cony",
            "Coot",
            "Cougar",
            "Cow",
            "Coyote",
            "Crab",
            "Crane",
            "Crocodile",
            "Crow",
            "Cuckoo",
            "Curlew",
            "Cuscus",
            "Cuttlefish",
            "Cygnet",
        ],
    },
    "d": {
        "adjectives": [
            "Daffy",
            "Dainty",
            "Dandy",
            "Dapper",
            "Daring",
            "Dastardly",
            "Daunting",
            "Dazzling",
            "Defiant",
            "Diligent",
            "Diplomatic",
            "Disarming",
            "Disco",
            "Discreet",
            "Disorderly",
            "Disruptive",
            "Dogmatic",
            "Doting",
            "Doubtful",
            "Dramatic",
            "Dreamy",
            "Droll",
            "Drowsy",
            "Drunk",
            "Drunken",
            "Dull",
            "Dumb",
            "Dumpy",
            "Dutiful",
            "Dynamic",
        ],
        "animals": [
            "Dachshund",
            "Dalmatian",
            "Damselfly",
            "Deer",
            "Dingo",
            "Dinosaur",
            "Diplodocus",
            "Dodo",
            "Dogfish",
            "Doe",
            "Dog",
            "Dolphin",
            "Donkey",
            "Dormouse",
            "Dove",
            "Drake",
            "Dragonfly",
            "Duck",
            "Dugong",
            "Dungbeetle",
            "Dzo",
        ],
    },
    "e": {
        "adjectives": [
            "Eager",
            "Earnest",
            "Easy",
            "Eccentric",
            "Eclectic",
            "Edgy",
            "Effervescent",
            "Elated",
            "Electric",
            "Elegant",
            "Elite",
            "Eloquent",
            "Elusive",
            "Eminent",
            "Emotional",
            "Empathetic",
            "Enchanting",
            "Encouraging",
            "Endearing",
            "Energetic",
            "Engaging",
            "Enigmatic",
            "Enlightened",
            "Enormous",
            "Enthusiastic",
            "Enticing",
            "Envious",
            "Ephemeral",
            "Epic",
            "Epicurean",
            "Erratic",
            "Euphoric",
            "Evangelizing",
            "Exquisite",
            "Extrovert",
        ],
        "animals": [
            "Eagle",
            "Earthworm",
            "Earwig",
            "Echidna",
            "Eel",
            "Eft",
            "Eland",
            "Elephant",
            "Elk",
            "Emu",
            "Ermine",
            "Escargot",
            "Euglena",
            "Ewe",
        ],
    },
    "f": {
        "adjectives": [
            "Fabulous",
            "Fair",
            "Faithful",
            "Fancy",
            "Fantastic",
            "Farsighted",
            "Fast",
            "Fearless",
            "Fecund",
            "Feisty",
            "Ferocious",
            "Festive",
            "Fierce",
            "Fiery" "Flaky",
            "Flamboyant",
            "Flashy",
            "Flawless",
            "Fluffy",
            "Flippant",
            "Fluent",
            "Flying",
            "Foxy",
            "Friendly",
            "Frisky",
            "Funky",
            "Furious",
            "Furry",
            "Fuzzy",
        ],
        "animals": [
            "Falcon",
            "Fawn",
            "Feline",
            "Fenix",
            "Fennec",
            "Ferret",
            "Fieldmouse",
            "Finch",
            "Finfoot",
            "Firefly",
            "Fish",
            "Flamingo",
            "Flight",
            "Fly",
            "Foundling",
            "Fox",
            "Frog",
            "Fruitbat",
            "Fugu",
            "Fulmar",
        ],
    },
    "g": {
        "adjectives": [
            "Gallant",
            "Galloping",
            "Galvanizing",
            "Gargantuan",
            "Gaudy",
            "Gentle",
            "Giddy",
            "Giggling",
            "Gleeful",
            "Glorious",
            "Glowing",
            "Gnarly",
            "Gobsmacked",
            "Goofy",
            "Gorgeous",
            "Graceful",
            "Gracious",
            "Grand",
            "Grandiose",
            "Grateful",
            "Great",
            "Greedy",
            "Gregarious",
            "Grim",
            "Grimacing",
            "Grinning",
            "Gritty",
            "Groaning" "Grizzly",
            "Groovy",
            "Grumpy",
            "Gutsy",
        ],
        "animals": [
            "Gadwall",
            "Galah",
            "Gannet",
            "Gappu",
            "Gator",
            "Gazelle",
            "Gecko",
            "Gerbil",
            "Germ",
            "Gibbon",
            "Gila",
            "Giraffe",
            "Gnarwhal",
            "Gnat",
            "Gnu",
            "Goat",
            "Gobbler",
            "Goldfinch",
            "Goose",
            "Gopher",
            "Gorilla",
            "Goshawk",
            "Grebe",
            "Groundhog",
            "Grue",
            "Guanaco",
            "Gull",
            "Guppy",
            "Gyrfalcon",
        ],
    },
    "h": {
        "adjectives": [
            "Hairy",
            "Half",
            "Handsome",
            "Happy",
            "Hardy",
            "Harmonious",
            "Harried",
            "Hasty",
            "Haughty",
            "Hawkish",
            "Hazardous",
            "Healthy",
            "Healthy",
            "Hearty",
            "Heavenly",
            "Heavy",
            "Helpful",
            "Helpless",
            "Heroic",
            "Hilarious",
            "Hippy",
            "Hirsute",
            "Hissing",
            "Hoary",
            "Holy",
            "Honest",
            "Hoopy",
            "Hopeful",
            "Hopping",
            "Horned",
            "Howling",
            "Huge",
            "Humble",
            "Humorous",
            "Hungry",
        ],
        "animals": [
            "Haddock",
            "Hagfish",
            "Hake",
            "Halibut",
            "Hammerhead",
            "Hamster",
            "Hare",
            "Harrier",
            "Hartebeest",
            "Hawk",
            "Hedgehog",
            "Hen",
            "Heron",
            "Herring",
            "Hippo",
            "Hog",
            "Hoopoe",
            "Hornbill",
            "Hornet",
            "Horse",
            "Hound",
            "Human",
            "Hummingbird",
            "Humpback",
            "Husky",
            "Hyacinth",
            "Hydra",
            "Hyena",
        ],
    },
    "i": {
        "adjectives": [
            "Idiosyncratic",
            "Idyllic",
            "Illuminating",
            "Illustrious",
            "Illustrious",
            "Imaginative",
            "Immaculate",
            "Immaterial",
            "Immense",
            "Imminent",
            "Immortal",
            "Impish",
            "Impressive",
            "Incomparable",
            "Incredible",
            "Indelible",
            "Industrious",
            "Inebriated",
            "Ineffable",
            "Inescapable",
            "Inexorable",
            "Infallible",
            "Ingenious",
            "Ingratiating",
            "Innocent",
            "Innovatory",
            "Inquisitive",
            "Insatiable",
            "Inscrutable",
            "Insightful",
            "Inspirational",
            "Inspired",
            "Intelligent",
            "Intimidated",
            "Intrepid",
            "Iridescent",
            "Itchy",
        ],
        "animals": [
            "Ibex",
            "Ibis",
            "Ichthyosaur",
            "Iguana",
            "Iguanodon",
            "Iguanosaurus",
            "Iliosuchus",
            "Ilokelesia",
            "Impala",
            "Incisivosaurus",
            "Indosaurus",
            "Indosuchus",
            "Indri",
            "Ingenia",
            "Inkanyamba",
            "Inosaurus",
            "Insect",
            "Irukandji",
            "Isanosaurus",
            "Ischisaurus",
            "Ischyrosaurus",
            "Isisaurus",
            "Isopoda",
            "Issasaurus",
            "Itemirus",
            "Iuticosaurus",
        ],
    },
    "j": {
        "adjectives": [
            "Jabbering",
            "Jaded",
            "Jaunty",
            "Jazzy",
            "Jealous",
            "Jiggly" "Jocular",
            "Jogging",
            "Jolly",
            "Jousting",
            "Jovial",
            "Joyous",
            "Jubilant",
            "Judicious",
            "Juggling",
            "Jumping",
            "Jumpy",
            "Jungle",
            "Jurassic",
            "Juvenile",
        ],
        "animals": [
            "Jacana",
            "Jackal",
            "Jackalope",
            "Jackass",
            "Jackrabbit",
            "Jaguar",
            "Javelina",
            "Jay",
            "Jellyfish",
            "Jerboa",
            "Joey",
            "Junco",
            "Junebug",
        ],
    },
    "k": {
        "adjectives": [
            "Kaleidoscopic",
            "Karmic",
            "Keen",
            "Kicking",
            "Kilted",
            "Kind",
            "Kinetic",
            "Kingly",
            "Kitschy",
            "Knightly",
        ],
        "animals": [
            "Kakapo",
            "Kalong",
            "Kangaroo",
            "Katydid",
            "Kea",
            "Kelpie",
            "Kestrel",
            "Killdeer",
            "Kingfisher",
            "Kinkajou",
            "Kite",
            "Kitten",
            "Kittiwake",
            "Kittyhawk",
            "Kiwi",
            "Koala",
            "Kodiak",
            "Kodkod",
            "Koi",
            "Kolibri",
            "Komodo",
            "Konqui",
            "Kookaburra",
            "Kouprey",
            "Kowari",
            "Kudu",
        ],
    },
    "l": {
        "adjectives": [
            "Lampooning",
            "Laudable",
            "Laughing",
            "Leal",
            "Leaping",
            "Leapy",
            "Lingual",
            "Lithe",
            "Lively",
            "Lofty",
            "Longhorn",
            "Loquacious",
            "Lovely",
            "Lucid",
            "Lucky",
            "Luminous",
            "Lunar",
        ],
        "animals": [
            "Labrador",
            "Ladybug",
            "Lagomorph",
            "Lamantin",
            "Lamb",
            "Lamprey",
            "Lapwing",
            "Lark",
            "Leafhopper",
            "Leech",
            "Lemming",
            "Lemur",
            "Leopard",
            "Leopon",
            "Liger",
            "Limpet",
            "Lion",
            "Lizard",
            "Llama",
            "Lobster",
            "Longhorn",
            "Loompa",
            "Loon",
            "Lorax",
            "Loris",
            "Louse",
            "Lynx",
            "Lycaon",
        ],
    },
    "m": {
        "adjectives": [
            "Magical",
            "Magistical",
            "Magnanimous",
            "Magnetic",
            "Magnificent",
            "Majestic",
            "Mammoth",
            "Marvelous",
            "Massive",
            "Masterful",
            "Maverick",
            "Meandering",
            "Measured",
            "Meaty",
            "Melancholic",
            "Mellifluous",
            "Mellow",
            "Melodic",
            "Memorable",
            "Mercurial",
            "Merry",
            "Meticulous",
            "Mighty",
            "Mindful",
            "Mini",
            "Minty",
            "Miraculous",
            "Mischievous",
            "Misty",
            "Mobile",
            "Modest",
            "Modish",
            "Momentous",
            "Monastic",
            "Monty",
            "Moral",
            "Muscular",
            "Musical",
            "Musky",
            "Mysterious",
            "Mystic",
            "Mythical",
        ],
        "animals": [
            "Macaque",
            "Macaw",
            "Macropod",
            "Maggot",
            "Magpie",
            "Mallard",
            "Mammoth",
            "Manatee",
            "Mandrill",
            "Manta",
            "Mantis",
            "Mara",
            "Marlin",
            "Marmot",
            "Marsupilami",
            "Marten",
            "Mastiff",
            "Meadowlark",
            "Meerkat",
            "Meglodon",
            "Millipede",
            "Mink",
            "Minnow",
            "Mobutu",
            "Mockingbird",
            "Mole",
            "Mollusk",
            "Molly",
            "Monal",
            "Monca",
            "Mongoose",
            "Monitor",
            "Monkey",
            "Moose",
            "Mosquito",
            "Moth",
            "Motmot",
            "Mouflon",
            "Mouse",
            "Mule",
            "Muskox",
            "Muskrat",
            "Mustang",
            "Mutt",
            "Myna",
        ],
    },
    "n": {
        "adjectives": [
            "Naked",
            "Narrow",
            "Nano",
            "Naughty",
            "Nautical",
            "New",
            "Nice",
            "Nerdy",
            "Nested",
            "Nifty",
            "Nimble",
            "Noble",
            "Nocturnal",
            "Noisy",
            "Nomadic",
            "Normal",
            "Nostalgic",
            "Novel",
            "Nuclear",
            "Numb",
        ],
        "animals": [
            "Naiad",
            "Narwhal",
            "Natterjack",
            "Nautilus",
            "Newt",
            "Nightingale",
            "Nightjar",
            "Numbat",
            "Nuthatch",
            "Nutria",
            "Nymph",
        ],
    },
    "o": {
        "adjectives": [
            "Obedient",
            "Oblivious",
            "Obsequious",
            "Observing",
            "Obtuse",
            "Obverse",
            "Odd",
            "Okay",
            "Omniscient",
            "Oneiric",
            "Opportunistic",
            "Opulent",
            "Orderly",
            "Ordinary",
            "Orthodox",
            "Ostentatious",
        ],
        "animals": [
            "Ocelot",
            "Octopus",
            "Okapi",
            "Opossum",
            "Orangutan",
            "Orca",
            "Oriole",
            "Oryx",
            "Ostrich",
            "Otter",
            "Owl",
            "Ox",
            "Oyster",
        ],
    },
    "p": {
        "adjectives": [
            "Pacific",
            "Paramount",
            "Passive",
            "Peachy",
            "Perceptive",
            "Perennial",
            "Perky",
            "Persistent",
            "Persnickety",
            "Phat",
            "Philantropic",
            "Philosophical",
            "Photogenic",
            "Pink",
            "Playful",
            "Plucky",
            "Plutonic",
            "Poetic",
            "Polished",
            "Posh",
            "Powerful",
            "Pragmatic",
            "Prancing",
            "Precocious",
            "Prestigious",
            "Pretty",
            "Prickly",
            "Prideful",
            "Prissy",
            "Pristine",
            "Proactive",
            "Prolific",
            "Proud",
            "Prowling",
            "Prudent",
            "Psychedelic",
            "Psychic",
            "Purring",
        ],
        "animals": [
            "Pademelon",
            "Panda",
            "Pangolin",
            "Panther",
            "Parakeet",
            "Parrot",
            "Partridge",
            "Peacock",
            "Peafowl",
            "Peccary",
            "Pegasus",
            "Pelican",
            "Penguin",
            "Pheasant",
            "Phoenix",
            "Pichi",
            "Pig",
            "Pigeon",
            "Piglet",
            "Pika",
            "Piraña",
            "Piranha",
            "Pitbull",
            "Pixi",
            "Platypus",
            "Polecat",
            "Pony",
            "Porcupine",
            "Porpoise",
            "Possum",
            "Primate",
            "Pronghorn",
            "Protozoa",
            "Puffin",
            "Puma",
            "Python",
        ],
    },
    "q": {
        "adjectives": [
            "Quaint",
            "Quaking",
            "Qualified",
            "Quantal",
            "Quantum",
            "Quasi",
            "Quick",
            "Quiet",
            "Quintessential",
            "Quirky",
            "Quivering",
            "Quixotic",
            "Quizzical",
        ],
        "animals": [
            "Qantassaurus",
            "Quagga",
            "Quahog",
            "Quail",
            "Quetzal",
            "Quetzalcoatl",
            "Quokka",
            "Quoll",
        ],
    },
    "r": {
        "adjectives": [
            "Racing",
            "Radiant",
            "Radical",
            "Rambunctious",
            "Randy",
            "Rapid",
            "Raring",
            "Rational",
            "Ravenous",
            "Ravishing",
            "Reasonable",
            "Rebel",
            "Rednosed",
            "Reformed",
            "Regal",
            "Relaxed",
            "Relentless",
            "Reliable",
            "Relieved",
            "Remarkable",
            "Reminiscent",
            "Rhetorical",
            "Rhythmic",
            "Ribald",
            "Rich",
            "Rival",
            "Roaring",
            "Robust",
            "Rowdy",
            "Rugged",
        ],
        "animals": [
            "Rabbit",
            "Raccoon",
            "Raptor",
            "Rat",
            "Ratel",
            "Rattlesnake",
            "Raven",
            "Redbird",
            "Reindeer",
            "Reptile",
            "Rhea",
            "Rhino",
            "Ringtail",
            "Roach",
            "Roadrunner",
            "Robin",
            "Rook",
            "Rooster",
            "Rottweiler",
            "Ruff",
        ],
    },
    "s": {
        "adjectives": [
            "Sage",
            "Salivating",
            "Sanguine",
            "Sarcastic",
            "Sassy",
            "Saucy",
            "Scrawny",
            "Sentimental",
            "Serendipitous",
            "Serious",
            "Servile",
            "Shrewd",
            "Slick",
            "Slim",
            "Smiling",
            "Smitten",
            "Smooth",
            "Snazzy",
            "Sneaky",
            "Soaring",
            "Sophisticated",
            "Sound",
            "Speedy",
            "Spotty",
            "Sprightly",
            "Stalwart",
            "Stealthy",
            "Stocky",
            "Strapping",
            "Streetwise",
            "Striking",
            "Stunning",
            "Stupendous",
            "Sturdy",
            "Suave",
            "Surreptitious",
            "Swarthy",
        ],
        "animals": [
            "Sabretooth",
            "Salamander",
            "Salmon",
            "Saola",
            "Scallop",
            "Scorpion",
            "Scorpionfish",
            "Scottie",
            "Seadonkey",
            "Seagull",
            "Seahorse",
            "Seal",
            "Serval",
            "Shark",
            "Sheep",
            "Shih-Tzu",
            "Shrew",
            "Silverfish",
            "Sitatunga",
            "Skunk",
            "Slippershell",
            "Sloth",
            "Snail",
            "Snake",
            "Snapper",
            "Spaniel",
            "Sparrow",
            "Spider",
            "Springbok",
            "Squid",
            "Squirrel",
            "Stallion",
            "Starfish",
            "Stingray",
            "Suricate",
            "Swallow",
            "Swan",
            "Swordfish",
            "Stegosaurus",
        ],
    },
    "t": {
        "adjectives": [
            "Tabby",
            "Tactful",
            "Talented",
            "Tame",
            "Tangled",
            "Tasteful",
            "Tasty",
            "Temperate",
            "Tenable",
            "Tenacious",
            "Tender",
            "Terrific",
            "Thankful",
            "Therapeutic",
            "Thorough",
            "Thoughtful",
            "Thrifty",
            "Thrilled",
            "Thrilling",
            "Thriving",
            "Ticklish",
            "Tidy",
            "Tight",
            "Timely",
            "Timeless",
            "Tiny",
            "Tireless",
            "Tolerant",
            "Tough",
            "Trailblazing",
            "Tranquil",
            "Transcendent",
            "Transcendental",
            "Traveled",
            "Treasured",
            "Tremendous",
            "Trim",
            "Trippy",
            "Triumphant",
            "True",
            "Truculent",
            "Trustworthy",
            "Truthful",
            "Twirling",
        ],
        "animals": [
            "Tahr",
            "Taipan",
            "Takahe",
            "Tamandua",
            "Tapir",
            "Tarantula",
            "Tarsier",
            "Tasmanian-Devil",
            "Tenrec",
            "Tardigrade",
            "Termite",
            "Terrapin",
            "Terrier",
            "Tiger",
            "Tigon",
            "Tigerfish",
            "Toad",
            "Tortoise",
            "Toucan",
            "Trogon",
            "Trout",
            "Tuatara",
            "Turkey",
            "Turtle",
            "Triceratops",
            "Tyrannosaur",
            "Titanosaur",
        ],
    },
    "u": {
        "adjectives": [
            "Ultimate",
            "Unassailable",
            "Unassuming",
            "Unbelievable",
            "Underrated",
            "Understanding",
            "Unplugged",
            "Unpretentious",
            "Unrated",
            "Uproarious",
            "Ubiquitous",
            "Utopic",
        ],
        "animals": [
            "Uakari",
            "Uguisu",
            "Uintathere",
            "Umbrian",
            "Ungulate",
            "Urchin",
            "Urial",
            "Urubu",
            "Urukai",
            "Utonagan",
        ],
    },
    "v": {
        "adjectives": [
            "Valiant",
            "Valorous",
            "Vast",
            "Veracious",
            "Verdant",
            "Versatile",
            "Versed",
            "Veteran",
            "Vibrant",
            "Violent",
            "Violet",
            "Viral",
            "Virtuoso",
            "Virtuous",
            "Vivacious",
            "Vivid",
            "Vocal",
            "Vogue",
            "Voluptuous",
            "Voracious",
        ],
        "animals": [
            "Veery",
            "Velociraptor",
            "Vervet",
            "Vicuña",
            "Viper",
            "Vixen",
            "Vole",
            "Vulture",
        ],
    },
    "w": {
        "adjectives": [
            "Waggly",
            "Wandering",
            "Warm",
            "Warty",
            "Wary",
            "Washed",
            "Watchful",
            "Waterlogged",
            "Whimsical",
            "Whispering",
            "White",
            "Wholesome",
            "Wild",
            "Wily",
            "Wise",
            "Wistful",
            "Witty",
            "Wobbly",
            "Wonderful",
            "Woolly",
            "Wry",
        ],
        "animals": [
            "Wallaby",
            "Walrus",
            "Warthog",
            "Wasp",
            "Weasel",
            "Weevil",
            "Whale",
            "Whippet",
            "Wildebeest",
            "Wildcat",
            "Wolf",
            "Wolverine",
            "Wombat",
            "Woodchuck",
            "Woodpecker",
            "Worm",
            "Wren",
            "Weka",
        ],
    },
    "x": {
        "adjectives": [
            "Xanthic",
            "Xanthous",
            "Xenial",
            "Xeric",
            "Xylophonic",
        ],
        "animals": [
            "Xebu",
            "Xenarthra",
            "Xenoturbella",
            "Xenops",
            "Xerus",
            "Xiphias",
            "Xipho",
            "Xue Bao",
            "Xoloitzcuintle",
            "Xólotl",
        ],
    },
    "y": {
        "adjectives": [
            "Yakkity",
            "Yawning",
            "Yearning",
            "Yelling",
            "Yellow",
            "Yelping",
            "Yodeling",
            "Yogic",
            "Youthful",
            "Yummy",
            "Yuppie",
        ],
        "animals": [
            "Yaffle",
            "Yak",
            "Yellowjacket",
        ],
    },
    "z": {
        "adjectives": [
            "Zany",
            "Zealous",
            "Zen",
            "Zesty",
            "Zippy",
            "Zooming",
            "Zoophilic",
        ],
        "animals": [
            "Zebra",
            "Zebrafish",
            "Zebu",
            "Zooplankton",
            "Zorilla",
            "Zorse",
        ],
    },
}
